//
// main.go
// Copyright (C) 2017 kevin <kevin@ie.suberic.net>
//
// Distributed under terms of the MIT license.
//

package main

import (
	"flag"
	"html/template"
	"log"
	"net/http"

	"github.com/prometheus/client_golang/prometheus/promhttp"
	"gitlab.com/lyda/gqgmc/devices/geiger"
)

var addr = flag.String("listen-address", ":8080", "Address for HTTP requests.")
var device = flag.String("device", "/dev/gqgmc", "Device for Geiger Counter.")
var model = flag.String("model", "gqgmc", "Model of Geiger Counter.")

type indexPage struct {
	Model   string
	Version string
	Serial  string
	Volts   int16
	CPM     uint16
}

var gc geiger.Counter
var indexPg indexPage

func indexHandler(w http.ResponseWriter, r *http.Request) {
	indexPg.CPM, _ = gc.GetCPM()
	t, _ := template.ParseFiles("index.html")
	t.Execute(w, indexPg)
}

func main() {
	flag.Parse()

	gc, _ = geiger.New(geiger.Config{Model: *model, Device: *device})
	indexPg.Model = gc.Model()
	indexPg.Version = gc.Version()
	indexPg.Serial, _ = gc.SerialNum()
	indexPg.Volts, _ = gc.Volts()
	http.HandleFunc("/", indexHandler)
	http.Handle("/metrics", promhttp.Handler())
	log.Fatal(http.ListenAndServe(*addr, nil))
}
